summaryrefslogtreecommitdiffstats
path: root/lib/kofficeui/KoPageLayoutHeader.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficeui/KoPageLayoutHeader.h')
-rw-r--r--lib/kofficeui/KoPageLayoutHeader.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/lib/kofficeui/KoPageLayoutHeader.h b/lib/kofficeui/KoPageLayoutHeader.h
index 52239714..f1f9664f 100644
--- a/lib/kofficeui/KoPageLayoutHeader.h
+++ b/lib/kofficeui/KoPageLayoutHeader.h
@@ -16,14 +16,14 @@
* Boston, MA 02110-1301, USA.
*/
-#ifndef kopagelayoutheader_h
-#define kopagelayoutheader_h
+#ifndef kopagetqlayoutheader_h
+#define kopagetqlayoutheader_h
#include <KoUnit.h>
#include <KoPageLayout.h>
#include <KoPageLayoutHeaderBase.h>
-class QWidget;
+class TQWidget;
class KoUnitDoubleSpinBox;
class KoPagePreview;
@@ -32,15 +32,16 @@ class KoPagePreview;
*/
class KoPageLayoutHeader : public KoPageLayoutHeaderBase {
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Contructor
* @param parent the parent widget
* @param unit the unit-type (mm/cm/inch) that the dialog should show
* @param kwhf the data that this widget will be filled with initially
*/
- KoPageLayoutHeader(QWidget *parent, KoUnit::Unit unit, const KoKWHeaderFooter &kwhf);
+ KoPageLayoutHeader(TQWidget *tqparent, KoUnit::Unit unit, const KoKWHeaderFooter &kwhf);
/**
* @return the altered data as it is currently set by the user.
*/
@@ -32,15 +32,16 @@ class KoPagePreview;
/**
* Contructor
- * @param parent the parent widget
+ * @param tqparent the tqparent widget
* @param unit the unit-type (mm/cm/inch) that the dialog should show
* @param kwhf the data that this widget will be filled with initially